@@ -83,9 +83,10 @@ class Session(dict):
         self.request_func,self.rfunc_from_paths = self.mapUri(self.request.path)
         if not self.request_func:
             self.request_func=self.onNotFound
-        self.onOpen(request,None)
-        if self.rfunc_from_paths:self.request_func_result = self.request_func(self,self.request,None)
-        # dict-mapped objects
+
+        if self.rfunc_from_paths and not hasattr(self,self.request_func.__name__):
+            self.request_func_result = self.request_func(self,self.request,None)
+        # dict-mapped objects outside current class
         else:self.request_func_result = self.request_func(self.request,None)            
         # native objects
         self.set_session()            # saves session dict
